/* 
Visualizza la cambiata sul display 7 segmenti.

Funziona sia ad anodo comune, sia a catodo comune, cambiando una variabile.

I segmenti sono collegati come nei "define".
Il punto decimale non è collegato.
Resistori di pulldown da 10K sugli input.
*/


// Associamo ai pin dell'arduino:
// i segmenti del display...
#define ledA    6
#define ledB    9
#define ledC    4
#define ledD    3
#define ledE    2
#define ledF    7
#define ledG    8

// ...e i pulsanti delle marce
#define SU       12
#define GIU      10

// Mappiamo i numeri e i simboli (1==acceso, 0==spento)
const byte cifre[14] = {
  B0000111, // -1
  B0000001, // 0
  B0110000, // 1
  B1101101, // 2
  B1111001, // 3
  B0110011, // 4
  B1011011, // 5
  B0011111, // 6
  B1110000, // 7
  B1111111, // 8
  B1110011, // 9
  B0010101, // U alta
  B0010101, // U bassa
  B0000000, // nulla
};


// Definiamo alcune costanti
const byte ultima_marcia = 7; // la marcia più alta del simulatore
const boolean anodo_comune = 1; // settare a 1 se usiamo un display ad anodo comune
const int ritardo_cambiata = 200; // per quanto tempo minimo appare la u (fa anche da antirimbalzo)

const byte segmenti[7] = {ledG,ledF,ledE,ledD,ledC,ledB,ledA};

byte n = 1; // la prima marcia

boolean stato_su;
boolean stato_giu;
  
  
void setup() 
{
  for (byte i=0; i<7; i++) {
    pinMode(segmenti[i], OUTPUT);
  } //for
  
  pinMode(SU, INPUT);
  pinMode(GIU, INPUT);

} //setup


void loop()
{
  
  stato_su = digitalRead(SU);
  stato_giu = digitalRead(GIU);
  
  mostraCifra(n);
  
  if(stato_su) {
    if(n < ultima_marcia) {
      mostraCifra(12);
      delay(ritardo_cambiata);
      stato_su = digitalRead(SU);
      while(stato_su) {
        delay(1);
        stato_su = digitalRead(SU);
    } // while
      n++;
    } // if
    else { // Se la marcia è già quella più alta...
      lampeggiaCifra(n);
      
    } // else
  } // if
  
  if(stato_giu) {
    if(n > 0) {
      mostraCifra(12);
      delay(ritardo_cambiata);
      stato_giu = digitalRead(GIU);
      while(stato_giu) {
        delay(1);
        stato_giu = digitalRead(GIU);
    } // while
      n--;
    } // if
    else {  // Se siamo già in prima...
      lampeggiaCifra(n);
    } // else
  } // if
  
} //loop 


// Definiamo la funzione per mostrare le cifre
void mostraCifra(byte cifra)
{
  boolean acceso_spento;
  for (byte i=0; i<7; i++) {
    acceso_spento =  bitRead(cifre[cifra], i);
    if (anodo_comune) { acceso_spento = ! acceso_spento ; }
    digitalWrite(segmenti[i], acceso_spento);
  } //for
} // function


// E la funzione per farle lampeggiare
void lampeggiaCifra(byte x)
 {
   for (byte i=0; i<4; i++) {
     mostraCifra(13);
     delay(100);
     mostraCifra(x);
     delay(20);
   } // for
 } // function
